@@ -6,7 +6,7 @@ from . import google
 from . import stutils
 from . import meteo
 from . import easy_import
-from .pickle_wrapper import load_pickle, dump_pickle
+# from .pickle_wrapper import load_pickle, dump_pickle
 from .regress2 import regress2
 
 __all__ = [
@@ -14,7 +14,7 @@ __all__ = [
     "Montre", 
     "create_all_parents", "searching_all_files", "unzip", "pbar",
     "load_google_drive", "google",
-    "load_pickle", "dump_pickle",
+    # "load_pickle", "dump_pickle",
     "stutils", "regress2",
     "easy_import"
     ]
\ No newline at end of file
